#[repr(transparent)]pub struct ExitCode(pub i32);Tuple Fields
0: i32Trait Implementations
Sourceimpl Termination for ExitCode
impl Termination for ExitCode
Sourcefn report(self) -> ProcessExitCode
fn report(self) -> ProcessExitCode
Is called to get the representation of the value as status code.
This status code is returned to the operating system.
impl Copy for ExitCode